package lib.exporter;

import kernel.peripherals.IPeripheral;
import kernel.log.Log;

using tink.CoreApi;

class Export {
	private final exportConfig:ExportConfig;
	private final peripheral:IPeripheral;

	public function new<T:IExportable & IPeripheral>(exportPerph:T) {
		this.peripheral = exportPerph;
		this.exportConfig = exportPerph.export();
	}

	public function handleRequest(req:Request):Response {
		switch (req.operation) {
			case Get:
				return handleGet(req);
			case Set(value):
				// TODO: implement
				return NotFound;
		}
	}

	private function handleGet(request:Request):Response {
		if (!this.exportConfig.getDelegates.exists(request.field)) {
			Log.warn('Requested get field ${request.field} does not exist in ??');
			return NotFound;
		}

		var delegate = this.exportConfig.getDelegates.get(request.field);
		var value = delegate(request.index);

		return Get(value);
	}

	public function getType():String {
		return this.peripheral.getType();
	}

	public function getAddr():String {
		return this.peripheral.getAddr();
	}
}
